%global _python_bytecompile_extra 0
%global _smp_ncpus_max 4

%global major 2
%define libname %mklibname fwupd %major
%define devname %mklibname -d fwupd
%global glib2_version 2.45.8
%global libxmlb_version 0.1.3
%global libgusb_version 0.3.5
%global libcurl_version 7.62.0
%global libjcat_version 0.1.0
%global systemd_version 231
%global json_glib_version 1.1.1

# although we ship a few tiny python files these are utilities that 99.99%
# of users do not need -- use this to avoid dragging python onto CoreOS
%global __requires_exclude ^%{python3}$

# PPC64 is too slow to complete the tests under 3 minutes...
%ifnarch ppc64le
%global enable_tests 1
%endif

%global enable_dummy 1

# fwupd.efi is only available on these arches
%ifarch x86_64 aarch64
%global have_uefi 1
%endif

# gpio.h is only available on these arches
%ifarch x86_64 aarch64
%global have_gpio 1
%endif

# flashrom is only available on these arches
%ifarch %ix86 x86_64 armv7hl aarch64 ppc64le
%global have_flashrom 1
%endif

%ifarch %ix86 x86_64
%global have_msr 1
%endif

# libsmbios is only available on x86
%ifarch x86_64
%global have_dell 1
%endif

# Until we actually have seen it outside x86
%ifarch %ix86 x86_64
%global have_thunderbolt 1
%endif

# only available recently
%if 0%{?mageia} >= 9
%global have_modem_manager 1
%endif

Summary:   Firmware update daemon
Name:      fwupd
Group:     System/Kernel and hardware
Version:   1.9.5
Release:   %mkrel 1
License:   LGPLv2+
URL:       https://github.com/fwupd/fwupd
Source0:   https://people.freedesktop.org/~hughsient/releases/%{name}-%{version}.tar.xz

BuildRequires: gettext
BuildRequires: glib2-devel >= %{glib2_version}
BuildRequires: libxmlb-devel >= %{libxmlb_version}
BuildRequires: pkgconfig(libgcab-1.0)
BuildRequires: pkgconfig(gudev-1.0)
BuildRequires: libgusb-devel >= %{libgusb_version}
BuildRequires: libcurl-devel >= %{libcurl_version}
BuildRequires: pkgconfig(mm-glib)
BuildRequires: pkgconfig(jcat) >= %{libjcat_version}
BuildRequires: polkit-devel >= 0.103
BuildRequires: protobuf-c-devel
BuildRequires: python3-packaging
BuildRequires: sqlite3-devel
BuildRequires: systemd >= %{systemd_version}
BuildRequires: systemd-devel
BuildRequires: libarchive-devel
BuildRequires: libcbor-devel
BuildRequires: pkgconfig(passim)
BuildRequires: gobject-introspection-devel
BuildRequires: gcab
%ifarch %{valgrind_arches}
BuildRequires: valgrind
BuildRequires: valgrind-devel
%endif
BuildRequires: gi-docgen
BuildRequires: gnutls-devel
BuildRequires: gnutls
BuildRequires: meson
BuildRequires: json-glib-devel >= %{json_glib_version}
BuildRequires: vala
BuildRequires: bash-completion
BuildRequires: git-core
%if 0%{?have_flashrom}
BuildRequires: flashrom-devel >= 1.2-2
%endif

%if 0%{?have_modem_manager}
BuildRequires: modemmanager-devel >= 1.10.0
BuildRequires: qmi-devel >= 1.22.0
BuildRequires: mbim-devel
%endif

%if 0%{?have_uefi}
BuildRequires: python3 python3-cairo python3-gobject3
BuildRequires: pango-devel
BuildRequires: cairo-devel pkgconfig(cairo-gobject)
BuildRequires: freetype2-devel
BuildRequires: fontconfig-devel
BuildRequires: google-noto-sans-cjk-ttc-fonts
BuildRequires: tpm2-tss-devel >= 2.2.3
%endif

%if 0%{?have_dell}
BuildRequires: efivar-devel >= 33
BuildRequires: pkgconfig(libsmbios_c) >= 2.4.0
%endif

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: shared-mime-info

Obsoletes: dbxtool < 9
Provides: dbxtool

Obsoletes: fwupdate < 12-3

# optional, but a really good idea
Recommends: udisks2
Recommends: bluez
Recommends: jq

%if 0%{?have_modem_manager}
Recommends: %{name}-plugin-modem-manager
%endif
%if 0%{?have_flashrom}
Recommends: %{name}-plugin-flashrom
%endif
%if 0%{?have_uefi}
Recommends: %{name}-efi
Recommends: %{name}-plugin-uefi-capsule-data
Obsoletes: fwupdate-efi < 12-3
%endif

Conflicts:  %{mklibname fwupd 0} <= 1.8.3

%description
fwupd is a daemon to allow session software to update device firmware.

%package -n %libname
Summary: Library for fwupd daemon
Group: System/Libraries
# (tv) fix conflict & upgrade:
Conflicts:  %{mklibname fwupd 0} <= 1.8.6-2.mga9

Obsoletes: %{_lib}fwup1 < 12-3

%description -n %libname
Library for fwupd daemon.

%package -n %devname
Group: Development/C
Summary: Development package for %{name}
Requires: %{libname} = %{version}-%{release}
Provides: fwupd-devel = %{version}-%{release}

Obsoletes: %{_lib}fwup-devel < 12-3

%description -n %devname
Files for development with %{name}.

%package tests
Summary: Data files for installed tests
Requires: %{name}%{?_isa} = %{version}-%{release}

%description tests
Data files for installed tests.

%if 0%{?have_modem_manager}
%package plugin-modem-manager
Summary: fwupd plugin using ModemManger
Requires: %{name}%{?_isa} = %{version}-%{release}

%description plugin-modem-manager
This provides the optional package which is only required on hardware that
might have mobile broadband hardware. It is probably not required on servers.
%endif

%if 0%{?have_flashrom}
%package plugin-flashrom
Summary: fwupd plugin using flashrom
Requires: %{name}%{?_isa} = %{version}-%{release}

%description plugin-flashrom
This provides the optional package which is only required on hardware that
can be flashed using flashrom. It is probably not required on servers.
%endif

%if 0%{?have_uefi}
%package plugin-uefi-capsule-data
Summary: Localized data for the UEFI UX capsule
Requires: %{name}%{?_isa} = %{version}-%{release}

%description plugin-uefi-capsule-data
This provides the pregenerated BMP artwork for the UX capsule, which allows the
"Installing firmware update…" localized text to be shown during a UEFI firmware
update operation. This subpackage is probably not required on embedded hardware
or server machines.
%endif

%prep
%autosetup -p1

%build

%meson \
    -Ddocs=enabled \
%if 0%{?enable_tests}
    -Dtests=true \
%else
    -Dtests=false \
%endif
%if 0%{?enable_dummy}
    -Dplugin_dummy=true \
%else
    -Dplugin_dummy=false \
%endif
%if 0%{?have_flashrom}
    -Dplugin_flashrom=enabled \
%else
    -Dplugin_flashrom=disabled \
%endif
%if 0%{?have_msr}
    -Dplugin_msr=enabled \
%else
    -Dplugin_msr=disabled \
%endif
%if 0%{?have_gpio}
    -Dplugin_gpio=enabled \
%else
    -Dplugin_gpio=disabled \
%endif
%if 0%{?have_uefi}
    -Dplugin_uefi_capsule=enabled \
    -Dplugin_uefi_pk=enabled \
    -Dplugin_tpm=enabled \
    -Defi_binary=false \
%else
    -Dplugin_uefi_capsule=disabled \
    -Dplugin_uefi_pk=disabled \
    -Dplugin_tpm=disabled \
%endif
%if 0%{?have_dell}
    -Dplugin_dell=enabled \
%else
    -Dplugin_dell=disabled \
%endif
%if 0%{?have_modem_manager}
    -Dplugin_modem_manager=enabled \
%else
    -Dplugin_modem_manager=disabled \
%endif
    -Dman=true \
    -Dbluez=enabled \
    -Dplugin_powerd=disabled \
    -Dsupported_build=enabled

%meson_build

%if 0%{?enable_tests}
%check
%meson_test || :
%endif

%install
%meson_install

mkdir -p --mode=0700 $RPM_BUILD_ROOT%{_localstatedir}/lib/fwupd/gnupg

# workaround for https://bugzilla.redhat.com/show_bug.cgi?id=1757948
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/cache/fwupd

%find_lang %{name}

%post
%systemd_post fwupd.service fwupd-refresh.timer

# change vendor-installed remotes to use the default keyring type
for fn in /etc/fwupd/remotes.d/*.conf; do
    if grep -q "Keyring=gpg" "$fn"; then
        sed -i 's/Keyring=gpg/#Keyring=pkcs/g' "$fn";
    fi
done

%preun
%systemd_preun fwupd.service fwupd-refresh.timer

%postun
%systemd_postun_with_restart fwupd.service fwupd-refresh.timer

%files -f %{name}.lang
%doc README.md
%license COPYING
%config(noreplace)%{_sysconfdir}/fwupd/fwupd.conf
%dir %{_libexecdir}/fwupd
%{_libexecdir}/fwupd/fwupd
%ifarch i686 x86_64
%{_libexecdir}/fwupd/fwupd-detect-cet
%endif
%{_libexecdir}/fwupd/fwupdoffline
%{_bindir}/dbxtool
%{_bindir}/fwupdmgr
%{_bindir}/fwupdtool
%dir %{_sysconfdir}/fwupd
%dir %{_sysconfdir}/fwupd/bios-settings.d
%{_sysconfdir}/fwupd/bios-settings.d/README.md
%dir %{_sysconfdir}/fwupd/remotes.d
%if 0%{?have_dell}
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/dell-esrt.conf
%endif
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/lvfs.conf
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/lvfs-testing.conf
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/vendor.conf
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/vendor-directory.conf
%config(noreplace)%{_sysconfdir}/pki/fwupd
%{_sysconfdir}/pki/fwupd-metadata
%if 0%{?have_msr}
/usr/lib/modules-load.d/fwupd-msr.conf
%endif
%{_datadir}/dbus-1/system.d/org.freedesktop.fwupd.conf
%{_datadir}/bash-completion/completions/fwupdmgr
%{_datadir}/bash-completion/completions/fwupdtool
%{_datadir}/fish/vendor_completions.d/fwupdmgr.fish
%{_datadir}/fwupd/metainfo/org.freedesktop.fwupd*.metainfo.xml
%if 0%{?have_dell}
%{_datadir}/fwupd/remotes.d/dell-esrt/metadata.xml
%endif
%{_datadir}/fwupd/remotes.d/vendor/firmware/README.md
%{_datadir}/dbus-1/interfaces/org.freedesktop.fwupd.xml
%{_datadir}/polkit-1/actions/org.freedesktop.fwupd.policy
%{_datadir}/polkit-1/rules.d/org.freedesktop.fwupd.rules
%{_datadir}/dbus-1/system-services/org.freedesktop.fwupd.service
%{_mandir}/man1/fwupdtool.1*
%{_mandir}/man1/dbxtool.*
%{_mandir}/man1/fwupdmgr.1*
%{_mandir}/man5/*
%{_mandir}/man8/*
%{_datadir}/metainfo/org.freedesktop.fwupd.metainfo.xml
%{_datadir}/icons/hicolor/scalable/apps/org.freedesktop.fwupd.svg
%{_datadir}/fwupd/firmware_packager.py
%{_datadir}/fwupd/simple_client.py
%{_datadir}/fwupd/add_capsule_header.py
%{_datadir}/fwupd/install_dell_bios_exe.py
%{_unitdir}/fwupd-offline-update.service
%{_unitdir}/fwupd.service
%{_unitdir}/fwupd-refresh.service
%{_unitdir}/fwupd-refresh.timer
%{_unitdir}/system-update.target.wants/
%dir %{_localstatedir}/lib/fwupd
%dir %{_localstatedir}/cache/fwupd
%dir %{_datadir}/fwupd/quirks.d
%{_datadir}/fwupd/quirks.d/builtin.quirk.gz
%{_datadir}/doc/fwupd/*.html
%if 0%{?have_uefi}
%config(noreplace)%{_sysconfdir}/grub.d/35_fwupd
%endif
%{_libdir}/girepository-1.0/Fwupd-2.0.typelib
/usr/lib/udev/rules.d/*.rules
/usr/lib/systemd/system-shutdown/fwupd.shutdown
%dir %{_libdir}/fwupd-%{version}
%{_libdir}/fwupd-%{version}/libfwupd*.so
%ghost %{_localstatedir}/lib/fwupd/gnupg

%if 0%{?have_modem_manager}
%files plugin-modem-manager
%{_libdir}/fwupd-%{version}/libfu_plugin_modem_manager.so
%endif
%if 0%{?have_flashrom}
%files plugin-flashrom
%{_libdir}/fwupd-%{version}/libfu_plugin_flashrom.so
%endif
%if 0%{?have_uefi}
%files plugin-uefi-capsule-data
%{_datadir}/fwupd/uefi-capsule-ux.tar.xz
%endif

%files -n %libname
%{_libdir}/libfwupd*.so.%{major}.*
%{_libdir}/libfwupd*.so.%{major}

%files -n %devname
%{_datadir}/gir-1.0/Fwupd-2.0.gir
%{_datadir}/doc/fwupd/libfwupdplugin
%{_datadir}/doc/fwupd/libfwupd
%{_datadir}/doc/libfwupdplugin
%{_datadir}/doc/libfwupd
%{_datadir}/vala/vapi
%{_includedir}/fwupd-1
%{_libdir}/libfwupd*.so
%{_libdir}/pkgconfig/fwupd.pc

%files tests
%if 0%{?enable_tests}
%{_datadir}/fwupd/host-emulate.d/*.json.gz
%dir %{_datadir}/installed-tests/fwupd
%{_datadir}/installed-tests/fwupd/tests/*
%{_datadir}/installed-tests/fwupd/fwupd-tests.xml
%{_datadir}/installed-tests/fwupd/*.test
%{_datadir}/installed-tests/fwupd/*.cab
%{_datadir}/installed-tests/fwupd/*.sh
%{_datadir}/installed-tests/fwupd/*.zip
%if 0%{?have_uefi}
%{_datadir}/installed-tests/fwupd/efi
%endif
%{_datadir}/installed-tests/fwupd/chassis_type
%{_datadir}/installed-tests/fwupd/sys_vendor
# libgusb >= 0.4.5
%if 0%{?mageia} >= 9
%{_datadir}/fwupd/device-tests/*.json
%endif
%{_libexecdir}/installed-tests/fwupd/*
%dir %{_sysconfdir}/fwupd/remotes.d
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/fwupd-tests.conf
%endif


%changelog
* Tue Sep 26 2023 tv <tv> 1.9.5-1.mga10
+ Revision: 1991078
- BR passim
- 1.9.5

* Tue Jan 10 2023 daviddavid <daviddavid> 1.8.9-2.mga9
+ Revision: 1932165
- obsoletes remaining fwupdate pkgs

* Wed Jan 04 2023 tv <tv> 1.8.9-1.mga9
+ Revision: 1929751
- 1.8.9

* Fri Dec 09 2022 tv <tv> 1.8.8-1.mga9
+ Revision: 1919678
- 1.8.8

* Fri Nov 25 2022 kekepower <kekepower> 1.8.7-5.mga9
+ Revision: 1911120
- Obsolete fwupdate

* Wed Nov 16 2022 tv <tv> 1.8.7-4.mga9
+ Revision: 1908016
- Fix upgrade

* Wed Nov 16 2022 tv <tv> 1.8.7-3.mga9
+ Revision: 1907919
- Fix major
- Fix file conflict

* Tue Nov 15 2022 tv <tv> 1.8.7-2.mga9
+ Revision: 1907478
- 1.8.7
- Fix the lvfs-testing remote

* Sat Oct 08 2022 tv <tv> 1.8.6-2.mga9
+ Revision: 1895412
- Disable theunderbolt on !x86
- Ignore the one failing test for now
- 1.8.4
+ guillomovitch <guillomovitch>
- new version 1.8.6
+ neoclust <neoclust>
- New version 1.8.5
- Add conflicts to ease upgrade

* Fri Aug 05 2022 tv <tv> 1.8.3-1.mga9
+ Revision: 1875347
- 1.8.3

* Fri Jul 22 2022 tv <tv> 1.8.2-1.mga9
+ Revision: 1870115
- 1.8.2
- 1.8.2

* Thu May 05 2022 tv <tv> 1.8.0-2.mga9
+ Revision: 1856294
- 1.8.0

* Thu Apr 07 2022 tv <tv> 1.7.7-1.mga9
+ Revision: 1847126
- 1.7.7

* Tue Apr 05 2022 umeabot <umeabot> 1.7.6-2.mga9
+ Revision: 1844864
- Mageia 9 Mass Rebuild

* Mon Mar 07 2022 tv <tv> 1.7.6-1.mga9
+ Revision: 1789452
- 1.7.6

* Fri Feb 11 2022 tv <tv> 1.7.5-1.mga9
+ Revision: 1773025
- 1.7.5

* Wed Jan 19 2022 tv <tv> 1.7.4-1.mga9
+ Revision: 1769023
- 1.7.4

* Tue Dec 14 2021 tv <tv> 1.7.3-1.mga9
+ Revision: 1762145
- New upstream release (1.7.3)

* Mon Nov 22 2021 tv <tv> 1.7.2-1.mga9
+ Revision: 1758537
- New upstream release (1.7.2)

* Tue Nov 02 2021 tv <tv> 1.7.1-1.mga9
+ Revision: 1753648
- New upstream release (1.7.1)

* Mon Oct 11 2021 tv <tv> 1.7.0-1.mga9
+ Revision: 1750572
- New upstream release (1.7.0)

* Tue Aug 17 2021 tv <tv> 1.6.3-1.mga9
+ Revision: 1741751
- 1.6.3

* Mon Jun 14 2021 tv <tv> 1.6.1-1.mga9
+ Revision: 1730730
- 1.6.1

* Tue May 25 2021 tv <tv> 1.6.0-1.mga9
+ Revision: 1728101
- 1.6.0
- Backport https://github.com/fwupd/fwupd/pull/3144 (rhbz#1949491)
- 1.5.9

* Sun Mar 28 2021 tv <tv> 1.5.8-1.mga9
+ Revision: 1711294
- Restrict to 4 CPUs in order to workaround missing build deps
- 1.5.8

* Sun Feb 28 2021 tv <tv> 1.5.7-1.mga9
+ Revision: 1693257
- 1.5.7

* Tue Jan 12 2021 tv <tv> 1.5.5-1.mga8
+ Revision: 1671409
- 1.5.5

* Wed Dec 16 2020 tv <tv> 1.5.4-1.mga8
+ Revision: 1658060
- 1.5.4

* Wed Dec 09 2020 tv <tv> 1.5.3-1.mga8
+ Revision: 1654874
- 1.5.3

* Mon Nov 23 2020 tv <tv> 1.5.2-1.mga8
+ Revision: 1648803
- 1.5.2

* Sat Nov 21 2020 tv <tv> 1.5.1-3.mga8
+ Revision: 1648065
- Backport #2605 for #2600, seems to help RHBZ#1896540

* Wed Nov 04 2020 tv <tv> 1.5.1-2.mga8
+ Revision: 1642510
- fix filelist
- 1.5.1
- Use UDisks to find out if swap devices are encrypted
- 1.5.0

* Tue Sep 08 2020 tv <tv> 1.4.6-3.mga8
+ Revision: 1623560
- 1.4.6
- 1.4.6

* Tue Aug 18 2020 tv <tv> 1.4.5-3.mga8
+ Revision: 1615424
- rebuild for new libxmlb

* Tue Aug 04 2020 tv <tv> 1.4.5-2.mga8
+ Revision: 1610912
- Make dual signing happen (CVE-2020-10713)

* Sat Aug 01 2020 tv <tv> 1.4.5-1.mga8
+ Revision: 1610278
- 1.4.5

* Thu Jun 11 2020 tv <tv> 1.4.4-1.mga8
+ Revision: 1592266
- 1.4.4

* Sat May 23 2020 tv <tv> 1.4.2-2.mga8
+ Revision: 1587125
- Backport a patch to fix the synaptics fingerprint reader update.

* Mon May 18 2020 tv <tv> 1.4.2-1.mga8
+ Revision: 1586059
- 1.4.2

* Mon Apr 27 2020 tv <tv> 1.4.1-1.mga8
+ Revision: 1572478
- 1.4.1

* Tue Apr 14 2020 tv <tv> 1.4.0-1.mga8
+ Revision: 1567303
- 1.4.0

* Sun Apr 05 2020 tv <tv> 1.3.9-1.mga8
+ Revision: 1564955
- 1.3.9

* Tue Feb 18 2020 umeabot <umeabot> 1.3.8-2.mga8
+ Revision: 1541843
- Mageia 8 Mass Rebuild

* Fri Feb 14 2020 tv <tv> 1.3.8-1.mga8
+ Revision: 1521994
- new release

* Tue Feb 11 2020 tv <tv> 1.3.7-1.mga8
+ Revision: 1490440
- new release

* Thu Jan 02 2020 tv <tv> 1.3.6-1.mga8
+ Revision: 1475593
- New upstream release

* Sat Dec 21 2019 tv <tv> 1.3.5-1.mga8
+ Revision: 1469234
- New upstream release

* Tue Nov 12 2019 tv <tv> 1.3.3-1.mga8
+ Revision: 1459694
- 1.3.3

* Thu Oct 31 2019 tv <tv> 1.3.2-1.mga8
+ Revision: 1457198
- disable %%_python_bytecompile_extra
- new release

* Tue Jul 23 2019 tv <tv> 1.2.10-1.mga8
+ Revision: 1423554
- new release

* Wed Jul 10 2019 tv <tv> 1.2.9-1.mga8
+ Revision: 1419883
- new release

* Tue May 14 2019 tv <tv> 1.2.8-1.mga7
+ Revision: 1397680
- new release
+ umeabot <umeabot>
- Rebuild with meson 0.50.1

* Tue Feb 19 2019 wally <wally> 1.2.3-4.mga7
+ Revision: 1368322
- fix devel pkg names in BRs

* Thu Jan 31 2019 tv <tv> 1.2.3-3.mga7
+ Revision: 1362090
- fix deps

* Thu Jan 31 2019 tv <tv> 1.2.3-2.mga7
+ Revision: 1362072
- add dev provides

* Thu Jan 31 2019 tv <tv> 1.2.3-1.mga7
+ Revision: 1362057
- new release
+ ovitters <ovitters>
- imported package fwupd

